@@ -55,7 +55,8 @@ void KPGAggregatesFolder::refresh() throw(const KPGSqlException &)
 			
     try
     {
-        m_pqxxResultAggregates = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		m_pqxxResultAggregates = pConnection->runQuery(strQuery);
 
         KPGAggregate *pAggregate = 0;
             
@@ -66,7 +67,7 @@ void KPGAggregatesFolder::refresh() throw(const KPGSqlException &)
             else
                 pAggregate = new KPGAggregate(this, pAggregate, m_pqxxResultAggregates[i]["aggrname"].c_str());
                 
-            pAggregate->setProperties(m_pqxxResultAggregates[i]);
+            pAggregate->setProperties(m_pqxxResultAggregates[i], pConnection);
         }
     }
     catch (const std::exception &e)
