@@ -62,7 +62,8 @@ void KPGDomainConstraintsFolder::refresh(pqxx::oid oidDomain) throw(const KPGSql
         
     try
     {
-        m_pqxxResultConstraints = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		m_pqxxResultConstraints = pConnection->runQuery(strQuery);
         
         KPGDomainConstraint * pDomainConstraint = 0;
         
@@ -76,7 +77,7 @@ void KPGDomainConstraintsFolder::refresh(pqxx::oid oidDomain) throw(const KPGSql
             else
                 pDomainConstraint = new KPGDomainConstraint(this, pDomainConstraint, m_pqxxResultConstraints[i]["conname"].c_str(), oid);
                 
-            pDomainConstraint->setProperties(m_pqxxResultConstraints[i]);
+            pDomainConstraint->setProperties(m_pqxxResultConstraints[i], pConnection);
         }
     }
     catch (const std::exception &e)
