@@ -48,7 +48,8 @@ void KPGDomainsFolder::refresh() throw(const KPGSqlException &)
 			
     try
     {
-        m_pqxxResultDomains = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+        m_pqxxResultDomains = pConnection->runQuery(strQuery);
     
         KPGDomain *pDomain = 0;
             
@@ -62,7 +63,7 @@ void KPGDomainsFolder::refresh() throw(const KPGSqlException &)
             else
                 pDomain = new KPGDomain(this, pDomain, m_pqxxResultDomains[i]["domname"].c_str(), oid);
             
-            pDomain->setProperties(m_pqxxResultDomains[i]);
+            pDomain->setProperties(m_pqxxResultDomains[i], pConnection);
             pDomain->refreshConstraints(); 
         }
     }
