@@ -23,6 +23,44 @@
 #include "kpgfunctionsfolder.h"
 #include "../kpgutil.h"
 
+KPGFunctionArgument::KPGFunctionArgument(unsigned int iSequence, 
+    const QString & strName, 
+    const QString & strMode, 
+    const QString & strTypName)
+{
+    m_iSequence = iSequence;
+    m_strName = strName;
+    m_strTypName = strTypName;
+        
+    if(strMode == "i")
+    {
+        m_eMode = input;
+    }
+    else if(strMode == "o")
+    {
+        m_eMode = output;
+    }
+    else if(strMode == "b")
+    {
+        m_eMode = inout;
+    }
+    else
+    {
+        m_eMode = input; // Default mode is IN
+    }
+}
+
+KPGFunctionArgument::KPGFunctionArgument(unsigned int iSequence, 
+                                         const QString & strName, 
+                                         EMode eMode, 
+                                         const QString & strTypName)
+{
+    m_iSequence = iSequence;
+    m_strName = strName;
+    m_strTypName = strTypName;
+    m_eMode = eMode;
+}
+
 KPGFunction::KPGFunction(KPGFunctionsFolder *parent, const QString name, pqxx::oid _oid)
  : KPGObject(parent, name, _oid)
 {
@@ -40,16 +78,17 @@ KPGFunction::~KPGFunction()
 {
 }
 
-void KPGFunction::setProperties(const pqxx::result::tuple &pqxxTuple)
+void KPGFunction::setProperties(const pqxx::result::tuple &pqxxTuple,
+								const KPGConnection *pConnection)
 {
 	pqxxTuple["proisagg"].to(m_bIsAgg);
 	pqxxTuple["prosecdef"].to(m_bIsSecdef);
 	pqxxTuple["proisstrict"].to(m_bIsStrict);
 	pqxxTuple["proretset"].to(m_bReturnSet);
-	pqxxTuple["pronargs"].to(m_iNArgs);
+	pqxxTuple["pronargs"].to(m_uiNArgs);
     pqxxTuple["prorettype"].to(m_oidReturnType);
 				
-	m_strDescription = pqxxTuple["description"].c_str();
+	m_strDescription = pConnection->toUnicode(pqxxTuple["description"].c_str());
 	m_strVolatile = pqxxTuple["provolatile"].c_str();
 	m_strBin = pqxxTuple["probin"].c_str();
 	m_strACL = pqxxTuple["proacl"].c_str();
@@ -89,7 +128,7 @@ void KPGFunction::setListArguments(const QString &strArgTypes, const QString &st
 		strListArgTypesOids = QStringList::split (" ", strArgTypes);		
 	
 	// Number of all arguments - max list size
-	unsigned int nArguments = m_iNArgs;
+	unsigned int nArguments = m_uiNArgs;
 	if(strListNames.count() > nArguments) nArguments = strListNames.count();
 	if(strListModes.count() > nArguments) nArguments = strListModes.count();
 	if(strListArgTypesOids.count() > nArguments) nArguments = strListArgTypesOids.count();
@@ -176,7 +215,7 @@ const QString KPGFunction::nameWithArguments() const
 // Return arguments, with names and IN/OUT info. 
 const QString KPGFunction::arguments() const
 {
-	if(m_iNArgs != m_listArguments.count())
+	if(m_uiNArgs != m_listArguments.count())
 	{
 		return argumentTypes();
 	}
@@ -184,7 +223,7 @@ const QString KPGFunction::arguments() const
 	QString strArguments("(");
 	
 	bool bFirst = true;
-	for(KPGFunction::ListArguments::const_iterator cit = m_listArguments.begin(); cit != m_listArguments.end(); ++cit)
+    for(ListFunctionArguments::const_iterator cit = m_listArguments.begin(); cit != m_listArguments.end(); ++cit)
 	{ 
 		if(bFirst)
 			bFirst = false;
@@ -235,7 +274,8 @@ typ.typname, lanname, pg_catalog.pg_get_userbyid(proowner) AS funcowner, pr.proa
 		
 	try
 	{
-		pqxx::result pqxxResult = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		pqxx::result pqxxResult = pConnection->runQuery(strQuery);
 	
 		if(pqxxResult.size() != 1)
 		{
@@ -243,10 +283,10 @@ typ.typname, lanname, pg_catalog.pg_get_userbyid(proowner) AS funcowner, pr.proa
 			return;
 		}
 				
-		setProperties(pqxxResult[0]);
+		setProperties(pqxxResult[0], pConnection);
 		
 		setArgTypes(pqxxResult[0]["arguments"].c_str());
-		setSrc(pqxxResult[0]["prosrc"].c_str());
+		setSourceCode(pConnection->toUnicode(pqxxResult[0]["prosrc"].c_str()));
 			
 		if(((pServer->versionMajor() == 8) && (pServer->versionMiddle() >= 1)) || (pServer->versionMajor() > 8))
     	{	
@@ -271,3 +311,13 @@ typ.typname, lanname, pg_catalog.pg_get_userbyid(proowner) AS funcowner, pr.proa
 	} 
 }
 
+void KPGFunction::setSourceCode(const QString &strSourceCode) 
+{ 
+	m_strSourceCode = strSourceCode; 
+	
+	// Strip the leading blank line from the source
+	if(m_strSourceCode.startsWith("\n"))
+	{
+		m_strSourceCode.replace(0, 1, "");
+	}
+}
