@@ -63,9 +63,10 @@ typ.typname, lanname, pg_catalog.pg_get_userbyid(proowner) as funcowner, pr.proa
 	strQuery.append("WHERE pronamespace = " + QString("%1").arg(m_oidNameSpace) + " ");
 	strQuery.append("ORDER BY proname");
 			
-  try
-  {
-    	m_pqxxResultFunctions = connection()->runQuery(strQuery);
+	try
+	{
+	  	KPGConnection *pConnection = connection();
+	 	m_pqxxResultFunctions = pConnection->runQuery(strQuery);
 
 		KPGFunction *pFunction = 0;
 		
@@ -79,10 +80,10 @@ typ.typname, lanname, pg_catalog.pg_get_userbyid(proowner) as funcowner, pr.proa
 				else
 					pFunction = new KPGFunction(this, pFunction, m_pqxxResultFunctions[i]["proname"].c_str(), oid);
 				
-				pFunction->setProperties(m_pqxxResultFunctions[i]);
+				pFunction->setProperties(m_pqxxResultFunctions[i], pConnection);
 				
 				pFunction->setArgTypes(m_pqxxResultFunctions[i]["arguments"].c_str());
-				pFunction->setSrc(m_pqxxResultFunctions[i]["prosrc"].c_str());
+				pFunction->setSourceCode(pConnection->toUnicode(m_pqxxResultFunctions[i]["prosrc"].c_str()));
 					
 				if(((pServer->versionMajor() == 8) && (pServer->versionMiddle() >= 1)) || (pServer->versionMajor() > 8))
     			{	
