@@ -80,7 +80,8 @@ ret.typname as resulttype, op.oprcom, co.oprname as compop, op.oprnegate, ne.opr
 			
     try
     {
-        m_pqxxResultOperators = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		m_pqxxResultOperators = pConnection->runQuery(strQuery);
     
         KPGOperator *pOperator = 0;
             
@@ -94,7 +95,7 @@ ret.typname as resulttype, op.oprcom, co.oprname as compop, op.oprnegate, ne.opr
             else
                 pOperator = new KPGOperator(this, pOperator, m_pqxxResultOperators[i]["oprname"].c_str(), oid);
                         
-            pOperator->setProperties(m_pqxxResultOperators[i], bVersion83_OrNewer);
+            pOperator->setProperties(m_pqxxResultOperators[i], bVersion83_OrNewer, pConnection);
         }
     }
     catch (const std::exception &e)
