@@ -51,7 +51,8 @@ void KPGRulesFolder::refresh(pqxx::oid oidTable) throw(const KPGSqlException &)
 			
 	try
 	{
-		m_pqxxResultRules = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		m_pqxxResultRules = pConnection->runQuery(strQuery);
 			
 		KPGRule *pRule = 0;
 			
@@ -65,16 +66,10 @@ void KPGRulesFolder::refresh(pqxx::oid oidTable) throw(const KPGSqlException &)
 			else
 				pRule = new KPGRule(this, pRule, m_pqxxResultRules[i]["rulename"].c_str(), oid);
 				
-			pRule->setProperties(m_pqxxResultRules[i]);
+			pRule->setProperties(m_pqxxResultRules[i], pConnection);
 					
 			//-- Get definition
-			strQuery = QString("SELECT pg_catalog.pg_get_ruledef(%1) AS definition;").arg(oid);
-			pqxx::result pqxxResultDefinition = connection()->runQuery(strQuery);
-			
-			if (pqxxResultDefinition.size() > 0)
-			{ 
-				pRule->setDefinition(pqxxResultDefinition[0][0].c_str());
-			}
+			pRule->refreshDefinition(pConnection);
 		}
 	}
 	catch (const std::exception &e)
