@@ -60,7 +60,8 @@ void KPGSequencesFolder::refresh() throw(const KPGSqlException &)
 			
     try
     {
-        m_pqxxResultSequences = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+        m_pqxxResultSequences = pConnection->runQuery(strQuery);
     
         KPGSequence *pSequence = 0;
             
@@ -74,7 +75,7 @@ void KPGSequencesFolder::refresh() throw(const KPGSqlException &)
             else
                 pSequence = new KPGSequence(this, pSequence, m_pqxxResultSequences[i]["relname"].c_str(), oid);
                             
-            pSequence->setProperties(m_pqxxResultSequences[i]);
+            pSequence->setProperties(m_pqxxResultSequences[i], pConnection);
                 
         
             if((pServer->versionMajor() >= 8) || ((pServer->versionMajor() == 7) && (pServer->versionMiddle() >= 4)))
