@@ -66,7 +66,8 @@ void KPGTableColumn::refreshItem() throw(const KPGSqlException &)
 	
 	try
 	{
-    	pqxx::result pqxxResultColumns = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+    	pqxx::result pqxxResultColumns = pConnection->runQuery(strQuery);
 
 		if(pqxxResultColumns.size() != 1)
 		{
@@ -74,7 +75,7 @@ void KPGTableColumn::refreshItem() throw(const KPGSqlException &)
 			return;
 		}
 		
-		setProperties(pqxxResultColumns[0]);
+		setProperties(pqxxResultColumns[0], pConnection);
 	}
 	catch (const std::exception &e)
 	{
@@ -83,7 +84,8 @@ void KPGTableColumn::refreshItem() throw(const KPGSqlException &)
 	} 
 }
 
-void KPGTableColumn::setProperties(const pqxx::result::tuple &pqxxTuple)
+void KPGTableColumn::setProperties(const pqxx::result::tuple &pqxxTuple,
+								   const KPGConnection *pConnection)
 {
 	pqxxTuple["atttypid"].to(m_oidType);
 	pqxxTuple["typbasetype"].to(m_oidBaseType);
@@ -100,7 +102,7 @@ void KPGTableColumn::setProperties(const pqxx::result::tuple &pqxxTuple)
 	pqxxTuple["attinhcount"].to(m_iInhCount);
 			
 	m_strTypName = pqxxTuple["typname"].c_str();
-	m_strDescription = pqxxTuple["description"].c_str();
+	m_strDescription = pConnection->toUnicode(pqxxTuple["description"].c_str());
 	m_strStorage = pqxxTuple["attstorage"].c_str();
 	m_strAdSrc = pqxxTuple["adsrc"].c_str();
 	m_strNspName = pqxxTuple["nspname"].c_str();
