@@ -56,7 +56,8 @@ void KPGTableConstraintsFolder::refresh(pqxx::oid oidTable) throw(const KPGSqlEx
 			
 	try
 	{
-		m_pqxxResultConstraints = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		m_pqxxResultConstraints = pConnection->runQuery(strQuery);
 			
 		KPGTableConstraint * pTableConstraint = 0;
 			
@@ -129,7 +130,7 @@ void KPGTableConstraintsFolder::refresh(pqxx::oid oidTable) throw(const KPGSqlEx
 					}    
 				}
 				
-				pTableConstraint->setProperties(m_pqxxResultConstraints[i]);
+				pTableConstraint->setProperties(m_pqxxResultConstraints[i], pConnection);
 			}
 	}
 	catch (const std::exception &e)
