@@ -94,7 +94,8 @@ void KPGTableIndex::refreshItem() throw(const KPGSqlException &)
 	
 	try
 	{
-    	pqxx::result pqxxResultIndexes = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		pqxx::result pqxxResultIndexes = pConnection->runQuery(strQuery);
 
 		if(pqxxResultIndexes.size() != 1)
 		{
@@ -102,7 +103,7 @@ void KPGTableIndex::refreshItem() throw(const KPGSqlException &)
 			return;
 		}
 
-		setProperties(pqxxResultIndexes[0], bVersion80_OrNewer, bVersion81_OrNewer);
+		setProperties(pqxxResultIndexes[0], bVersion80_OrNewer, bVersion81_OrNewer, pConnection);
 		
 	}
 	catch (const std::exception &e)
@@ -151,9 +152,11 @@ void KPGTableIndex::refreshMapIndexKey(pqxx::oid oidTable) throw(const KPGSqlExc
 
 // Set index properties
 void KPGTableIndex::setProperties(const pqxx::result::tuple & pqxxTuple, 
-    bool bVersion80_OrNewer, bool bVersion81_OrNewer)
+	bool bVersion80_OrNewer, 
+ 	bool bVersion81_OrNewer,
+	const KPGConnection *pConnection)
 {
-    m_strDescription = pqxxTuple["description"].c_str();
+	m_strDescription = pConnection->toUnicode(pqxxTuple["description"].c_str());
     m_strIndKey = pqxxTuple["indkey"].c_str();
     pqxxTuple["indisunique"].to(m_bIsUnique);
 	pqxxTuple["indisprimary"].to(m_bIsPrimary);
