@@ -96,7 +96,8 @@ despkey.description ELSE desidx.description END AS description, indkey, indisuni
 			
 	try
 	{
-		m_pqxxResultIndexes = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		m_pqxxResultIndexes = pConnection->runQuery(strQuery);
 		
 		KPGTableIndex *pTableIndex = 0;
 			
@@ -122,7 +123,7 @@ despkey.description ELSE desidx.description END AS description, indkey, indisuni
 					pTableIndex = new KPGIndex(this, pTableIndex, m_pqxxResultIndexes[i]["idxname"].c_str(), oid);
 			}
 				
-			pTableIndex->setProperties(m_pqxxResultIndexes[i], bVersion80_OrNewer, bVersion81_OrNewer);
+			pTableIndex->setProperties(m_pqxxResultIndexes[i], bVersion80_OrNewer, bVersion81_OrNewer, pConnection);
 			
 			// Load info about index columns
 			pTableIndex->refreshMapIndexKey(oidTable);
