@@ -105,7 +105,8 @@ void KPGTablesFolder::refresh() throw(const KPGSqlException &)
 	
   	try
   	{
-  	    m_pqxxResultTables = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		m_pqxxResultTables = pConnection->runQuery(strQuery);
 
 		KPGTable *pTable = 0;
 		
@@ -119,7 +120,7 @@ void KPGTablesFolder::refresh() throw(const KPGSqlException &)
 			else
 				pTable = new KPGTable(this, pTable, m_pqxxResultTables[i]["relname"].c_str(), oid);
 			
-			pTable->setProperties(m_pqxxResultTables[i], bVersion80_OrNewer, bVersion81_OrNewer);
+			pTable->setProperties(m_pqxxResultTables[i], bVersion80_OrNewer, bVersion81_OrNewer, pConnection);
 			
 			if(!bLazyLoadTablesChilds)
 			{
