@@ -72,7 +72,8 @@ void KPGTriggersFolder::refresh(pqxx::oid oidTable) throw(const KPGSqlException
 			
 	try
 	{
-		m_pqxxResultTriggers = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		m_pqxxResultTriggers = pConnection->runQuery(strQuery);
 			
 		KPGTrigger *pTrigger = 0;
 			
@@ -86,7 +87,7 @@ void KPGTriggersFolder::refresh(pqxx::oid oidTable) throw(const KPGSqlException
 			else
 				pTrigger = new KPGTrigger(this, pTrigger, m_pqxxResultTriggers[i]["tgname"].c_str(), oid);
 			
-			pTrigger->setProperties(m_pqxxResultTriggers[i]);
+			pTrigger->setProperties(m_pqxxResultTriggers[i], pConnection);
 		}
 	}
 	catch (const std::exception &e)
