@@ -37,7 +37,8 @@ KPGType::~KPGType()
 {
 }
 
-void KPGType::setProperties(const pqxx::result::tuple &pqxxTuple)
+void KPGType::setProperties(const pqxx::result::tuple &pqxxTuple,
+							const KPGConnection *pConnection)
 {
 	pqxxTuple["typlen"].to(m_iTypLen);
 	pqxxTuple["typbyval"].to(m_bByVal);
@@ -47,7 +48,7 @@ void KPGType::setProperties(const pqxx::result::tuple &pqxxTuple)
 	pqxxTuple["typoutputoid"].to(m_oidOutputFunc);
 	pqxxTuple["tableoid"].to(m_oidTable);
 			
-	m_strDescription = pqxxTuple["description"].c_str();
+	m_strDescription = pConnection->toUnicode(pqxxTuple["description"].c_str());
 	m_strKind = pqxxTuple["type"].c_str();
 	m_strTypDelim = pqxxTuple["typdelim"].c_str();
 	m_strTypAlign = pqxxTuple["align"].c_str();
@@ -92,7 +93,8 @@ void KPGType::refresh() throw(const KPGSqlException &)
 			
 	try
 	{
-		m_pqxxResultAttributes = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		m_pqxxResultAttributes = pConnection->runQuery(strQuery);
 		
 		KPGTypeAttribute *pTypeAttribute = 0;
 			
@@ -104,7 +106,7 @@ void KPGType::refresh() throw(const KPGSqlException &)
 				pTypeAttribute = new KPGTypeAttribute(this, pTypeAttribute, m_pqxxResultAttributes[i]["attname"].c_str());
 			
 							
-			pTypeAttribute->setProperties(m_pqxxResultAttributes[i]);
+			pTypeAttribute->setProperties(m_pqxxResultAttributes[i], pConnection);
 		}
 	}
 	catch (const std::exception &e)
@@ -129,7 +131,8 @@ void KPGType::refreshItem() throw(const KPGSqlException &)
 				
 	try
 	{
-    	pqxx::result pqxxResultTypes = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		pqxx::result pqxxResultTypes = pConnection->runQuery(strQuery);
 
 		if(pqxxResultTypes.size() != 1)
 		{
@@ -137,7 +140,7 @@ void KPGType::refreshItem() throw(const KPGSqlException &)
 			return;
 		}
 		
-		setProperties(pqxxResultTypes[0]);
+		setProperties(pqxxResultTypes[0], pConnection);
    
    	}
     catch (const std::exception &e)
