@@ -48,7 +48,8 @@ void KPGTypesFolder::refresh() throw(const KPGSqlException &)
 				
 	try
 	{
-		m_pqxxResultTypes = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		m_pqxxResultTypes = pConnection->runQuery(strQuery);
 	
 		KPGType *pType = 0;
 			
@@ -63,7 +64,7 @@ void KPGTypesFolder::refresh() throw(const KPGSqlException &)
 				pType = new KPGType(this, pType, m_pqxxResultTypes[i]["typname"].c_str(), oid);
 					
 								
-			pType->setProperties(m_pqxxResultTypes[i]);
+			pType->setProperties(m_pqxxResultTypes[i], pConnection);
 				
 			// Refresh attributes list
 			pType->refresh();
