@@ -51,7 +51,8 @@ void KPGViewsFolder::refresh() throw(const KPGSqlException &)
 		
   	try
 	{
-		m_pqxxResultViews = connection()->runQuery(strQuery);
+		KPGConnection *pConnection = connection();
+		m_pqxxResultViews = pConnection->runQuery(strQuery);
 	
 		KPGView *pgView = 0;
 			
@@ -72,13 +73,7 @@ void KPGViewsFolder::refresh() throw(const KPGSqlException &)
 					);
 					
 				//-- Get definition
-				strQuery = QString("SELECT pg_catalog.pg_get_viewdef(%1) AS definition;").arg(oid);
-				pqxx::result pqxxResultDefinition = connection()->runQuery(strQuery);
-			
-				if (pqxxResultDefinition.size() > 0)
-				{ 
-					pgView->setDefinition(pqxxResultDefinition[0][0].c_str());
-				}	
+				pgView->refreshDefinition(pConnection);
 		}
 	}
 	catch (const std::exception &e)
