@@ -40,13 +40,16 @@
 #include "kpgexecutorchildview.h"
 
 #define NUM_OF_RECORDS_PER_PAGE 500 // How many records are loaded to result table 
-#define UPDATE_TIMER_INTERVAL 1000 // 1 sec for updatiing code completion
 
+// Parameters table columns
 #define COL_NAME 0
 #define COL_TYPE_NAME 1
 #define COL_MODE 2
 #define COL_VALUE 3
 
+#define TAB_PAGE_RESULT_TABLE 0
+#define TAB_PAGE_RESULT_TEXT 1
+
 KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
 	KPoGreView *pPoGreView,
 	KXMLGUIFactory *pXmlGuiFactory,
@@ -55,12 +58,13 @@ KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
 	KPGFunction *pFunction)
 	: 
 	KXMLGUIClient(pPoGreView),
-	KPGExecutorBase(parent, "Executor"),
- 	m_pFind(0)
+    KPGExecutorBase(parent, "KPGExecutor"),
+    m_pFind(0),
+    m_pXmlGuiFactory(pXmlGuiFactory)
 {
 	// Setup GUI
+    //setFactory(pXmlGuiFactory);
 	setXMLFile("kpgexecutor.rc", true);
-	m_pXmlGuiFactory = pXmlGuiFactory;
 	m_bIsAddedToGuiFactory = false;
 	
 	// Initialize members
@@ -71,9 +75,10 @@ KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
 	m_nTotalRows = 0;
 	m_nTotalCols = 0;
 	m_nFetchedRows = 0;
-	
+    m_bParametersNotEntered = true;
+    
 	//-----------------------------------------------------------------
-	// Executor actions       
+	// Executor actions
 	m_pActExecute = new KAction(i18n("Execute"), "exec", Key_F8, this, SLOT(slotExecute()), actionCollection(), "executor_execute");
 	
 	m_pActStop = new KAction(i18n("Stop"), "stop", 0, this, SLOT(slotStop()), actionCollection(), "executor_stop");
@@ -101,6 +106,22 @@ KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
     //-----------------------------------------------------------------
     connect(m_pTableResult, SIGNAL(contextMenuRequested(int, int, const QPoint &)), this, SLOT(slotContextMenuRequested(int, int, const QPoint &)));
     
+    //-----------------------------------------------------------------
+    // Initial actions state 
+    m_pActExecute->setEnabled(true);
+    m_pActStop->setEnabled(false);
+    m_pActFetchNext->setEnabled(false); 
+    m_pActFetchAll->setEnabled(false);
+    
+    m_pActFindInResult->setEnabled(false);
+    m_pActFindNextInResult->setEnabled(false);
+    
+    m_pActCopyCell->setEnabled(false);
+    m_pActCopyRow->setEnabled(false);
+    m_pActCopyTableCsv->setEnabled(false);
+    m_pActCopyTableXml->setEnabled(false);
+    
+    //-----------------------------------------------------------------
 	// Setup tab icons
 	m_pTabWidget->setTabIconSet(pTabResult, QIconSet(QPixmap(SmallIcon("view_text"))));
 	m_pTabWidget->setTabIconSet(pTabTextResult, QIconSet(QPixmap(SmallIcon("openterm"))));
@@ -110,12 +131,12 @@ KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
 	m_listArguments = pFunction->listArguments();
 	
 	// Set-up parameters table
-	if(pFunction->listArguments().count() > 0)
+    if(m_listArguments.count() > 0)
 	{
-		m_pTableParameters->setNumRows(pFunction->listArguments().count());
+        m_pTableParameters->setNumRows(m_listArguments.count());
 		int nRow = 0;
 		
-		for(KPGFunction::ListArguments::const_iterator cit = pFunction->listArguments().begin(); cit != pFunction->listArguments().end(); ++cit)
+        for(ListFunctionArguments::const_iterator cit = m_listArguments.begin(); cit != m_listArguments.end(); ++cit)
 		{ 
 			m_pTableParameters->setText(nRow, COL_NAME, (*cit).name());
 			
@@ -128,9 +149,7 @@ KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
 			}
 			
 			
-			if((*cit).mode() == "i") m_pTableParameters->setText(nRow, COL_MODE, "IN");
-			else if((*cit).mode() == "o") m_pTableParameters->setText(nRow, COL_MODE, "OUT");
-			else if((*cit).mode() == "b") m_pTableParameters->setText(nRow, COL_MODE, "INOUT");
+            m_pTableParameters->setText(nRow, COL_MODE, (*cit).modeAsString());
 			nRow++;
 		}
 		
@@ -154,7 +173,7 @@ KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
 		m_connectionInThread.connectToServer(m_strConnectionOptions);
 		
 		KPGNoticer * pPgNoticer = m_connectionInThread.connection()->kpgNoticer();
-		connect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+        connect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 	}
 	catch (const std::exception &e)
 	{
@@ -162,17 +181,12 @@ KPGExecutor::KPGExecutor(KPGExecutorChildView *parent,
 		KMessageBox::sorry(this, e.what());
 		return;
 	}
-	
-	m_pActExecute->setEnabled(true);
-    m_pActStop->setEnabled(false);
-    m_pActFetchNext->setEnabled(false); 
-    m_pActFetchAll->setEnabled(false);
 }
 
 KPGExecutor::~KPGExecutor()
 {
 	KPGNoticer * pPgNoticer = m_connectionInThread.connection()->kpgNoticer();
-	disconnect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+    disconnect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 	
 	// Close connection
 	m_connectionInThread.disconnectFromServer(); // close connection if any
@@ -191,6 +205,7 @@ void KPGExecutor::addToGuiFactory()
 {
 	if(!m_bIsAddedToGuiFactory)
     {
+        //setFactory(m_pXmlGuiFactory);
         m_pXmlGuiFactory->addClient(this);
         m_bIsAddedToGuiFactory = true;
     }
@@ -201,6 +216,7 @@ void KPGExecutor::removeFromGuiFactory()
 {
     if(m_bIsAddedToGuiFactory)
     {
+        //setFactory(m_pXmlGuiFactory);
         m_pXmlGuiFactory->removeClient(this);
         m_bIsAddedToGuiFactory = false;
     }
@@ -209,7 +225,7 @@ void KPGExecutor::removeFromGuiFactory()
 // Display popup menu
 void KPGExecutor::slotContextMenuRequested(int, int, const QPoint &pos)
 {
-	QWidget * pContainer = m_pXmlGuiFactory->container("popupExecutorTable", this);
+    QWidget * pContainer = factory()->container("popupExecutorTable", this);
 
 	if ( ! pContainer )
 	{
@@ -279,11 +295,6 @@ void KPGExecutor::slotCopyTableXml()
 	KPGUtil::copyTableXml(m_pTableResult);
 }
 
-void KPGExecutor::updateActions()
-{
-	//emit sigExecutorStateChanged(this);
-}
-
 bool KPGExecutor::resultEmpty() const
 { 
 	return m_pTableResult->numRows() == 0; 
@@ -291,7 +302,33 @@ bool KPGExecutor::resultEmpty() const
 
 void KPGExecutor::executeFunction()
 {
-	// clear previous result
+    if(m_bParametersNotEntered)
+    {
+        int nArgs = m_pTableParameters->numRows();
+        for(int i = 0; i < nArgs; i++)
+        {
+            if(m_pTableParameters->text(i, COL_MODE) == "OUT")
+            {
+                continue; // skip OUTput parameters 
+            }
+            
+            if(m_pTableParameters->text(i, COL_VALUE).isEmpty()) 
+            {
+                if(KMessageBox::questionYesNo(this, i18n("Some parameters not set. Execute anyway ?"), "KPoGre") == KMessageBox::Yes) 
+                {
+                    m_bParametersNotEntered = false;
+                    break;
+                }
+                else 
+                {
+                    m_pTableParameters->setCurrentCell(i, COL_VALUE);
+                    return;
+                }
+            }
+        }
+    }
+    
+    // clear previous result
 	m_pTableResult->setNumRows(0);
 	m_pTableResult->setNumCols(0);
 	m_pTextEditResult->clear();
@@ -299,6 +336,8 @@ void KPGExecutor::executeFunction()
 	
 	m_pTextLabelExecutionTime->setText("");
 	m_pqxxResult.clear(); // free memory
+    m_nTotalRows = 0;
+    m_nTotalCols = 0;
 		
 	int iTransType = m_pComboBoxTransaction->currentItem();
 	KPGConnection::ETransType transType = KPGConnection::eTransNormal;
@@ -327,6 +366,11 @@ void KPGExecutor::executeFunction()
     m_pActFindInResult->setEnabled(false); 
     m_pActFindNextInResult->setEnabled(false);
 	m_pTableParameters->setEnabled(false);
+    
+    m_pActCopyCell->setEnabled(false);
+    m_pActCopyRow->setEnabled(false);
+    m_pActCopyTableCsv->setEnabled(false);
+    m_pActCopyTableXml->setEnabled(false);
 	
 	bool bSuccess = runSql(transType);
 	if(!bSuccess)
@@ -341,6 +385,11 @@ void KPGExecutor::executeFunction()
 
 void KPGExecutor::customEvent(QCustomEvent *pEvent)
 {
+	m_connectionInThread.wait();
+    
+    m_connectionInThread.unprepareStatement();
+    
+	
 	KPGQueryResultEvent *pQueryResultEvent = static_cast <KPGQueryResultEvent *> (pEvent);
 	
 	//kdDebug() << QString("Result size is: %1").arg(m_pqxxResult.size()) << endl;
@@ -350,11 +399,11 @@ void KPGExecutor::customEvent(QCustomEvent *pEvent)
 	{
 		displayExecutionTime(pQueryResultEvent->executionMiliseconds());   
 		displayResult(); 
-		m_pTabWidget->setCurrentPage(0);
+        m_pTabWidget->setCurrentPage(TAB_PAGE_RESULT_TABLE);
 	}
 	else
 	{
-		m_pTabWidget->setCurrentPage(1);
+        m_pTabWidget->setCurrentPage(TAB_PAGE_RESULT_TEXT);
 	}
 	
 	
@@ -371,15 +420,20 @@ void KPGExecutor::customEvent(QCustomEvent *pEvent)
 	m_pComboBoxTransaction->setEnabled(true);
 	//emit sigSetTerminalIcon(this, 2); // blue terminal icon
 	m_pTableParameters->setCursor(KCursor::arrowCursor());
-	
-	m_connectionInThread.wait();
-		
+			
 	m_pActExecute->setEnabled(true);
     m_pActStop->setEnabled(false);
     
     m_pActFetchNext->setEnabled((fetchedAllRows()) ? false : true); 
     m_pActFetchAll->setEnabled((fetchedAllRows()) ? false : true);
-    m_pActFindInResult->setEnabled((resultEmpty()) ?  false : true); 
+     
+    bool bResultNotEmpty = !resultEmpty();
+    
+    m_pActFindInResult->setEnabled(bResultNotEmpty);
+    m_pActCopyCell->setEnabled(bResultNotEmpty);
+    m_pActCopyRow->setEnabled(bResultNotEmpty);
+    m_pActCopyTableCsv->setEnabled(bResultNotEmpty);
+    m_pActCopyTableXml->setEnabled(bResultNotEmpty);
 }
 
 void KPGExecutor::stopExecute()
@@ -576,6 +630,7 @@ void KPGExecutor::fetchAll()
 // Run SQL to execute function on DB server
 bool KPGExecutor::runSql(KPGConnection::ETransType transType)
 {
+    // Construct calling SQL
 	QString strSql;
     
 	if(m_pCheckBoxExplain->isChecked())
@@ -600,26 +655,35 @@ bool KPGExecutor::runSql(KPGConnection::ETransType transType)
             
 	strSql.append("(");
     
-	int nArgs = m_pTableParameters->numRows();
-	for(int i = 0; i < nArgs; i++)
-	{
-		if(i > 0) strSql.append(", ");
+    int i = 1; // prepared arguments counter
+    int j = 0; // total arguments counter
+    unsigned int nRow = 0; // row in m_pTableParameters
+    for(ListFunctionArguments::const_iterator cit = m_listArguments.begin(); cit != m_listArguments.end(); ++cit)
+    { 
+        if((*cit).mode() == KPGFunctionArgument::output)
+        {
+            nRow++;
+            continue; // skip output arguments
+        }
+	
+        if(j++ > 0) strSql.append(", ");
     	
-		if((m_pTableParameters->text(i, COL_VALUE) == QString::null) || m_pTableParameters->text(i, COL_VALUE).isEmpty())
-		{
-			strSql.append("NULL");
-		}
-		else
-		{
-			strSql.append(QString("$%1").arg(i + 1));
-		}
-	}
+        if((m_pTableParameters->text(nRow, COL_VALUE) == QString::null) || m_pTableParameters->text(nRow, COL_VALUE).isEmpty())
+        {
+            strSql.append("NULL");
+        }
+        else
+        {
+            strSql.append(QString("$%1").arg(i++));
+        }
+        nRow++;
+    }
     
 	strSql.append(")"); 
     
 	kdDebug() << strSql << endl;
 	
-	if(nArgs == 0)
+    if(m_listArguments.size() == 0)
 	{
 		m_connectionInThread.setSQL(strSql, transType);
 	}
@@ -638,13 +702,18 @@ bool KPGExecutor::runSql(KPGConnection::ETransType transType)
 			pqxx::prepare::declaration pqxxPrepDecl = m_connectionInThread.connection()->prepare(strStatementName, strSql);
 		
 			// Add declaring parameters to prepared statements
-			for(int i = 0; i < nArgs; i++)
-			{
-				if((m_pTableParameters->text(i, COL_VALUE) != QString::null) && m_pTableParameters->text(i, COL_VALUE).isEmpty() == false)
-				{
-					m_connectionInThread.connection()->setPrepareDeclaration(pqxxPrepDecl, m_listArguments[i].typName());
-				}
-			}
+            unsigned int nRow = 0; // row in m_pTableParameters
+            for(ListFunctionArguments::const_iterator cit = m_listArguments.begin(); cit != m_listArguments.end(); ++cit)
+            { 
+                if((*cit).mode() != KPGFunctionArgument::output)
+                {
+                    if((m_pTableParameters->text(nRow, COL_VALUE) != QString::null) && m_pTableParameters->text(nRow, COL_VALUE).isEmpty() == false)
+				    {
+                        m_connectionInThread.connection()->setPrepareDeclaration(pqxxPrepDecl, (*cit).typName());
+				    }
+                }
+                nRow++;
+            }
 		}
 		catch(const std::exception &e)
 		{
@@ -655,17 +724,29 @@ bool KPGExecutor::runSql(KPGConnection::ETransType transType)
 		} 
 		
 		//***********************
-		ListArgumentsWithValues listArgumentsWithValues;
+        ListFunctionArgumentsWithValues listArgumentsWithValues;
 				
-		int currentArg = 0;
-		for(KPGFunction::ListArguments::iterator it = m_listArguments.begin(); it != m_listArguments.end(); ++it)
+		unsigned int nRow = 0;
+        for(ListFunctionArguments::const_iterator cit = m_listArguments.begin(); cit != m_listArguments.end(); ++cit)
 		{ 
-			if((m_pTableParameters->text(currentArg, COL_VALUE) == QString::null) 
-					|| m_pTableParameters->text(currentArg, COL_VALUE).isEmpty()) continue;
-						
-			listArgumentsWithValues.append(KPGFunctionArgumentWithValue(currentArg + 1, m_listArguments[currentArg].name(), m_listArguments[currentArg].mode(), m_listArguments[currentArg].typName(), m_pTableParameters->text(currentArg, COL_VALUE)));
-					
-			currentArg++;
+            if((*cit).mode() == KPGFunctionArgument::output)
+            {
+                nRow++;
+                continue;
+            }
+            
+            if((m_pTableParameters->text(nRow, COL_VALUE) == QString::null) 
+                || m_pTableParameters->text(nRow, COL_VALUE).isEmpty()) 
+            {
+                nRow++;
+                continue;
+            }
+            		
+            listArgumentsWithValues.append(KPGFunctionArgumentWithValue((*cit).sequence(), 
+                (*cit).name(), 
+                (*cit).mode(), 
+                (*cit).typName(), 
+                m_pTableParameters->text(nRow++, COL_VALUE)));
 		}
 		
 		m_connectionInThread.setPrepStatementArgumentValues(listArgumentsWithValues); 
@@ -787,10 +868,13 @@ void KPGExecutor::slotFindInResultNext()
 		}
 
     if( res == KFind::NoMatch ) 
-    { // i.e. at end
+    { 
+        // i.e. at end
+        m_pFind->closeFindNextDialog();
         m_pFind->displayFinalDialog();
         m_pFind->resetCounts();
         m_pTableResult->removeSelection(0);
+        m_pActFindNextInResult->setEnabled(false);
     }
 }
 
@@ -799,12 +883,19 @@ void KPGExecutor::slotHighlight( const QString &, int, int)
 {
     //kdDebug() << "highlight: " << index << " " << length << endl;
     m_pTableResult->setCurrentCell(m_iRowToSearch, m_iColToSearch);
+    m_pActFindNextInResult->setEnabled(true);
 }
 
 // Process notice from connection in thread
-void KPGExecutor::slotProcessNotice(QString strNotice)
+void KPGExecutor::slotProcessNotice(const QString & strNotice)
 {
 	qApp->lock();
 	m_pTextEditResult->append(strNotice);
 	qApp->unlock();
 }
+
+void KPGExecutor::virtual_hook(int id, void* data)
+{ 
+    KXMLGUIClient::virtual_hook(id, data); 
+}
+
