@@ -188,27 +188,30 @@ one."));
 	}
 	
 	//---
+	
+	QTextCodec * pTextCodec = pServer->connection()->textCodec();
+	
 	displayStatistics();
 	// displayCasts(); Lazy
-	displayLanguages();
-	displaySchemas();
-	displayExtendedStatistics();
+	displayLanguages(pTextCodec);
+	displaySchemas(pTextCodec);
+	displayExtendedStatistics(pTextCodec);
 }    
 
-void KPGDatabasePropPage::displayCasts()
-{
-    KPGUtil::fillPropertiesTable(m_pDatabase->resultCasts(), m_pTableCasts);
+void KPGDatabasePropPage::displayCasts(QTextCodec * pTextCodec)
+{	
+	KPGUtil::fillPropertiesTable(m_pDatabase->resultCasts(), m_pTableCasts, pTextCodec);
     m_bPageCastsDisplaied = true;
 }
 	
-void KPGDatabasePropPage::displayLanguages()
+void KPGDatabasePropPage::displayLanguages(QTextCodec * pTextCodec)
 {
-    KPGUtil::fillPropertiesTable(m_pDatabase->resultLanguages(), m_pTableLanguages);
+	KPGUtil::fillPropertiesTable(m_pDatabase->resultLanguages(), m_pTableLanguages, pTextCodec);
 }
 	
-void KPGDatabasePropPage::displaySchemas()
+void KPGDatabasePropPage::displaySchemas(QTextCodec * pTextCodec)
 {
-    KPGUtil::fillPropertiesTable(m_pDatabase->resultSchemas(), m_pTableSchemas);
+	KPGUtil::fillPropertiesTable(m_pDatabase->resultSchemas(), m_pTableSchemas, pTextCodec);
 }
 	
 void KPGDatabasePropPage::displayStatistics()
@@ -263,11 +266,14 @@ void KPGDatabasePropPage::displayStatistics()
 void KPGDatabasePropPage::slotRefreshStatistics()
 {
     setCursor(KCursor::waitCursor());
-  	displayExtendedStatistics();
-  	setCursor(KCursor::arrowCursor());
+	
+	QTextCodec * pTextCodec = m_pDatabase->connection()->textCodec();
+	displayExtendedStatistics(pTextCodec);
+  	
+	setCursor(KCursor::arrowCursor());
 }	
 	
-void KPGDatabasePropPage::displayExtendedStatistics()
+void KPGDatabasePropPage::displayExtendedStatistics(QTextCodec * pTextCodec)
 {
     m_pTableStatistics2->setNumRows(0);
     int currentItem = m_pComboBoxStatType->currentItem();
@@ -279,7 +285,7 @@ void KPGDatabasePropPage::displayExtendedStatistics()
 		pqxx::result pqxxResult = m_pDatabase->connection()->runQuery(strQuery);
 		
 		// fill properties table with result data
-		int nTableCols = KPGUtil::fillPropertiesTable(pqxxResult, m_pTableStatistics2, false);
+		int nTableCols = KPGUtil::fillPropertiesTable(pqxxResult, m_pTableStatistics2, pTextCodec, false);
 			
 		// field names
 		QHeader* hHeader = m_pTableStatistics2->horizontalHeader();
@@ -324,7 +330,8 @@ void KPGDatabasePropPage::slotRefreshLocks()
     	pqxx::result pqxxResult = m_pDatabase->connection()->runQuery(strQuery, KPGConnection::eTransNone);
     	    	
     	// fill properties table with result data
-		KPGUtil::fillPropertiesTable(pqxxResult, m_pTableLocks, false);
+		QTextCodec * pTextCodec = m_pDatabase->connection()->textCodec();
+		KPGUtil::fillPropertiesTable(pqxxResult, m_pTableLocks, pTextCodec, false);
     }
     catch (const std::exception &e)
 	{
@@ -358,7 +365,8 @@ void KPGDatabasePropPage::slotRefreshDiskUsage()
     	pqxx::result pqxxResult = m_pDatabase->connection()->runQuery(strQuery);
     	    	
     	// fill properties table with result data
-		KPGUtil::fillPropertiesTable(pqxxResult, m_pTableDiskUsage, false);
+		QTextCodec * pTextCodec = m_pDatabase->connection()->textCodec();
+		KPGUtil::fillPropertiesTable(pqxxResult, m_pTableDiskUsage, pTextCodec, false);
     }
     catch (const std::exception &e)
 	{
@@ -616,7 +624,10 @@ void KPGDatabasePropPage::slotCurrentTabChanged(QWidget *pPropertyPage)
 	if((pPropertyPage == tabCasts) && (!m_bPageCastsDisplaied))
 	{
 	   setCursor(KCursor::waitCursor());
-	   displayCasts();
+	   
+	   QTextCodec * pTextCodec = m_pDatabase->connection()->textCodec();
+	   displayCasts(pTextCodec);
+	   
 	   setCursor(KCursor::arrowCursor());	
 	}
 }
