@@ -133,7 +133,8 @@ KPGPropertyPageChildView::KPGPropertyPageChildView(KPoGreView *pPoGreView,
 	KXMLGUIFactory *pXmlGuiFactory)
  	:
  	KXMLGUIClient(pPoGreView), 
- 	KMdiChildView(i18n("Properties"), pPoGreView, "KPGPropertyPageChildView")
+ 	KMdiChildView(i18n("Properties"), pPoGreView, "KPGPropertyPageChildView"),
+    m_pXmlGuiFactory(pXmlGuiFactory)
 {
 	m_pPoGreView = pPoGreView;
 	
@@ -145,8 +146,8 @@ KPGPropertyPageChildView::KPGPropertyPageChildView(KPoGreView *pPoGreView,
 	setIcon( SmallIcon("info") );
 	
 	// Setup GUI
+    //setFactory(pXmlGuiFactory);
 	setXMLFile("kpgproppage.rc", true);
-	m_pXmlGuiFactory = pXmlGuiFactory;
 	m_bIsAddedToGuiFactory = false;
 	
 	//-----------------------------------------------------------------
@@ -172,7 +173,8 @@ void KPGPropertyPageChildView::addToGuiFactory()
 {
 	if(!m_bIsAddedToGuiFactory)
     {
-    	m_pXmlGuiFactory->addClient(this);
+        //setFactory(m_pXmlGuiFactory);
+        m_pXmlGuiFactory->addClient(this);
     	m_bIsAddedToGuiFactory = true;
     	//kdDebug() << k_funcinfo << endl;
     }
@@ -183,6 +185,7 @@ void KPGPropertyPageChildView::removeFromGuiFactory()
 {
     if(m_bIsAddedToGuiFactory)
     {
+        //setFactory(m_pXmlGuiFactory);
         m_pXmlGuiFactory->removeClient(this);
         m_bIsAddedToGuiFactory = false;
         //kdDebug() << k_funcinfo << endl;
@@ -765,7 +768,7 @@ bool KPGPropertyPageChildView::requestClose()
 
 void KPGPropertyPageChildView::slotTablePropContextMenuRequested(int, int, const QPoint & pos)
 {
-	QWidget * pContainer = m_pXmlGuiFactory->container("popupPropertyTable", this);
+    QWidget * pContainer = factory()->container("popupPropertyTable", this);
 
 	if ( ! pContainer )
 	{
@@ -783,3 +786,7 @@ void KPGPropertyPageChildView::slotTablePropContextMenuRequested(int, int, const
 	pMenu->popup( pos );
 }
 
+void KPGPropertyPageChildView::virtual_hook(int id, void* data)
+{ 
+    KXMLGUIClient::virtual_hook(id, data); 
+}
