@@ -17,6 +17,7 @@
 
 #include "../kpgutil.h"
 #include "../DbObjects/kpgtableconstraintsfolder.h"
+#include "../DbObjects/kpgconnection.h"
 
 KPGTableConstraintsFolderPropPage::KPGTableConstraintsFolderPropPage(QWidget* parent, KPGTableConstraintsFolder * pTableConstraintsFolder)
 	: KPGPropertyPage(parent, "KPGTableConstraintsFolderPropPage")
@@ -44,6 +45,8 @@ void KPGTableConstraintsFolderPropPage::displayProperties()
 	pHeader->setLabel(nCol++, i18n("Is Deferred"));
 	pHeader->setLabel(nCol++, i18n("Namespace"));
   
-  	KPGUtil::fillPropertiesTable(m_pTableConstraintsFolder->resultConstraints(), m_pTableItems);
+	QTextCodec * pTextCodec = m_pTableConstraintsFolder->connection()->textCodec();
+	
+	KPGUtil::fillPropertiesTable(m_pTableConstraintsFolder->resultConstraints(), m_pTableItems, pTextCodec);
 }
 
