@@ -206,13 +206,17 @@ void KPGTablePropPage::displayProperties()
 
 void KPGTablePropPage::displayColumns()
 {
-	KPGUtil::fillPropertiesTable(m_pTable->resultColumns(), m_pTableColumns);
+	QTextCodec * pTextCodec = m_pTable->connection()->textCodec();
+		
+	KPGUtil::fillPropertiesTable(m_pTable->resultColumns(), m_pTableColumns, pTextCodec);
 	m_bPageColumnsDisplaied = true;
 }
 
 void KPGTablePropPage::displayConstraints()
 {
-	KPGUtil::fillPropertiesTable(m_pTable->resultConstraints(), m_pTableConstraints);
+	QTextCodec * pTextCodec = m_pTable->connection()->textCodec();
+		
+	KPGUtil::fillPropertiesTable(m_pTable->resultConstraints(), m_pTableConstraints, pTextCodec);
 	m_bPageConstraintsDisplaied = true;
 }
 
@@ -222,19 +226,26 @@ void KPGTablePropPage::displayIndexes()
 	KPGServer *pServer = static_cast <KPGServer *> (pDatabase->parent());
 	
 	// fill properties table with result data
-	KPGUtil::fillPropertiesTable(m_pTable->resultIndexes(), m_pTableIndexes, true, (pServer->versionMajor() >= 8) ? 8 : 7);
+	QTextCodec * pTextCodec = m_pTable->connection()->textCodec();
+		
+	
+	KPGUtil::fillPropertiesTable(m_pTable->resultIndexes(), m_pTableIndexes, pTextCodec, true, (pServer->versionMajor() >= 8) ? 8 : 7);
 	m_bPageIndexesDisplaied = true;
 }
 
 void KPGTablePropPage::displayRules()
 {
-	KPGUtil::fillPropertiesTable(m_pTable->resultRules(), m_pTableRules);
+	QTextCodec * pTextCodec = m_pTable->connection()->textCodec();
+		
+	KPGUtil::fillPropertiesTable(m_pTable->resultRules(), m_pTableRules, pTextCodec);
 	m_bPageRulesDisplaied = true;
 }
 
 void KPGTablePropPage::displayTriggers()
 {
-	KPGUtil::fillPropertiesTable(m_pTable->resultTriggers(), m_pTableTriggers);
+	QTextCodec * pTextCodec = m_pTable->connection()->textCodec();
+		
+	KPGUtil::fillPropertiesTable(m_pTable->resultTriggers(), m_pTableTriggers, pTextCodec);
 	m_bPageTriggersDisplaied = false;
 }
 
