@@ -55,7 +55,7 @@ KPG2StepsWizard::~KPG2StepsWizard()
 	if(m_pConnection)
 	{
 		KPGNoticer * pPgNoticer = m_pConnection->kpgNoticer();
-		disconnect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+        disconnect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 	}
 }
 
@@ -64,7 +64,7 @@ void KPG2StepsWizard::setConnection(KPGConnection * pConnection)
 {
 	m_pConnection = pConnection;
 	KPGNoticer * pPgNoticer = pConnection->kpgNoticer();
-	connect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+    connect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 }
 
 void KPG2StepsWizard::showPage(QWidget *pPage)
@@ -112,7 +112,7 @@ void KPG2StepsWizard::showPage(QWidget *pPage)
 }
 
 // Process notice from connection
-void KPG2StepsWizard::slotProcessNotice(QString strNotice)
+void KPG2StepsWizard::slotProcessNotice(const QString & strNotice)
 {
 	m_listOfNotifications << strNotice;
 }
