@@ -54,7 +54,7 @@ KPG3StepsWizard::~KPG3StepsWizard()
 	if(m_pConnection)
 	{
 		KPGNoticer * pPgNoticer = m_pConnection->kpgNoticer();
-		disconnect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+        disconnect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 	}
 }
 
@@ -63,7 +63,7 @@ void KPG3StepsWizard::setConnection(KPGConnection * pConnection)
 {
 	m_pConnection = pConnection;
 	KPGNoticer * pPgNoticer = pConnection->kpgNoticer();
-	connect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+    connect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 }
 
 // Enable/disable next button for 1st page
@@ -112,7 +112,7 @@ void KPG3StepsWizard::runQuery(bool bWithTransaction)
 }
 
 // Process notice from connection
-void KPG3StepsWizard::slotProcessNotice(QString strNotice)
+void KPG3StepsWizard::slotProcessNotice(const QString & strNotice)
 {
 	m_listOfNotifications << strNotice;
 }
