@@ -55,7 +55,7 @@ KPG4StepsWizard::~KPG4StepsWizard()
 	if(m_pConnection)
 	{
 		KPGNoticer * pPgNoticer = m_pConnection->kpgNoticer();
-		disconnect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+        disconnect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 	}
 }
 
@@ -64,7 +64,7 @@ void KPG4StepsWizard::setConnection(KPGConnection * pConnection)
 {
 	m_pConnection = pConnection;
 	KPGNoticer * pPgNoticer = pConnection->kpgNoticer();
-	connect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+    connect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 }
 
 // Run SQL query - as final Wizard operation
@@ -119,7 +119,7 @@ void KPG4StepsWizard::slotEnableNextButton2(bool bEnable)
 }
 
 // Process notice from connection
-void KPG4StepsWizard::slotProcessNotice(QString strNotice)
+void KPG4StepsWizard::slotProcessNotice(const QString & strNotice)
 {
 	m_listOfNotifications << strNotice;
 }
