@@ -123,7 +123,7 @@ void KPG5StepsWizard::slotEnableNextButton3(bool bEnable)
 }
 
 // Process notice from connection
-void KPG5StepsWizard::slotProcessNotice(QString strNotice)
+void KPG5StepsWizard::slotProcessNotice(const QString & strNotice)
 {
 	m_listOfNotifications << strNotice;
 }
