@@ -54,7 +54,7 @@ KPG6StepsWizard::~KPG6StepsWizard()
 	if(m_pConnection)
 	{
 		KPGNoticer * pPgNoticer = m_pConnection->kpgNoticer();
-		disconnect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+        disconnect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 	}
 }
 
@@ -63,7 +63,7 @@ void KPG6StepsWizard::setConnection(KPGConnection * pConnection)
 {
 	m_pConnection = pConnection;
 	KPGNoticer * pPgNoticer = pConnection->kpgNoticer();
-	connect(pPgNoticer, SIGNAL(sigNotice(QString)), this, SLOT(slotProcessNotice(QString)));
+    connect(pPgNoticer, SIGNAL(sigNotice(const QString &)), this, SLOT(slotProcessNotice(const QString &)));
 }
 
 // Run SQL query - as final Wizard operation
@@ -130,7 +130,7 @@ void KPG6StepsWizard::slotEnableNextButton4(bool bEnable)
 }
 
 // Process notice from connection
-void KPG6StepsWizard::slotProcessNotice(QString strNotice)
+void KPG6StepsWizard::slotProcessNotice(const QString & strNotice)
 {
 	m_listOfNotifications << strNotice;
 }
