@@ -135,7 +135,7 @@ void KPG7StepsWizard::slotEnableNextButton5(bool bEnable)
 }
 
 // Process notice from connection
-void KPG7StepsWizard::slotProcessNotice(QString strNotice)
+void KPG7StepsWizard::slotProcessNotice(const QString & strNotice)
 {
 	m_listOfNotifications << strNotice;
 }
