@@ -13,30 +13,23 @@
 
 // include files for Qt
 #include <qstring.h>
-#include <qstringlist.h>
+#include <qtextcodec.h>
 
 // include files for KDE
 #include <kdebug.h>
 
 
-KPGNoticer::KPGNoticer(/*QStringList *pListOfNotifications*/)
-{
-	//m_pListOfNotifications = pListOfNotifications;
+KPGNoticer::KPGNoticer(QTextCodec *pTextCodec)
+{	
+	m_pTextCodec = pTextCodec;
 }
 
 void KPGNoticer::operator()(const char szMsg[]) throw ()
 {
-	/*if(!m_pListOfNotifications)
-	{
-		kdError() << k_funcinfo << ": m_pListOfNotifications is NULL !" << endl;
-		return;
-	}*/
-	
-	// Add notification to list
-	//*m_pListOfNotifications << szMsg;
-	emit sigNotice(QString(szMsg));
+	emit sigNotice(m_pTextCodec->toUnicode(szMsg));
 }
 
 KPGNoticer::~KPGNoticer() throw ()
 {
+	disconnect();
 }
