@@ -14,9 +14,7 @@
 KPGSqlException::KPGSqlException(const char* what, const QString & strSql)
  : std::runtime_error(what)
 {
-    m_strSql = strSql;
+    m_strSql =  strSql; // TODO convert using connection codec !
 }
 
 
-
-
