@@ -18,14 +18,14 @@
 #include <qstring.h>
 
 /**
-SQL Exception, contain info about SQL statement, that cause it
-
-	@author Lumir Vanek <lvanek@users.sourceforge.net>
-*/
+  * SQL Exception, contain info about SQL statement, that cause it
+  *
+  *	@author Lumir Vanek <lvanek@users.sourceforge.net>
+  */
 class KPGSqlException : public std::runtime_error
 {
 public:
-    KPGSqlException(const char* what, const QString & strSql);
+    KPGSqlException(const char*, const QString &);
     ~KPGSqlException() throw() {;}
 
     const QString & getSql() const { return m_strSql; }
