@@ -324,6 +324,8 @@ void KPoGreController::initActions(KActionCollection * pActionCollection)
     (void) new KAction( i18n("Execute function"), "exec", 0, this, SLOT(slotExecuteFunction()), pActionCollection, "execute_function" );
     
     (void) new KAction( i18n("Debug function"), "kpg_debugger", 0, this, SLOT(slotDebugFunction()), pActionCollection, "debug_function" );
+	
+	(void) new KAction( i18n("Attach to debugger"), "attach", 0, this, SLOT(slotDebugFunctionAttach()), pActionCollection, "debug_function_attach" );
         
     //--- Sequence related menu actions
     
@@ -399,7 +401,7 @@ void KPoGreController::initActions(KActionCollection * pActionCollection)
   	(void) new KAction( i18n("Set &owner"), 0, 0, this, SLOT(slotSetOwnerType()), pActionCollection, "set_owner_type" );
   
 	//--- Common menu actions
-	(void) new KAction( i18n("Set description..."), "comment", 0, this, SLOT(slotSetDescription()), pActionCollection, "set_description" ); 
+    (void) new KAction( i18n("Set description..."), "view_text", 0, this, SLOT(slotSetDescription()), pActionCollection, "set_description" ); 
   
 	//-----------------------------------------------------------------
 	// path toolbar
@@ -1346,13 +1348,21 @@ void KPoGreController::slotDebugFunction()
 {
 	slotStatusMsg(i18n("Debug function ..."));
 	
-	KMessageBox::sorry( m_pView, "Not implemented yet ...", "KPoGre");
-    return;
+	//KMessageBox::sorry( m_pView, "Not implemented yet ...", "KPoGre");
+    //return;
 	
-    //m_pView->debugFunction();
+    m_pView->debugFunction();
     slotStatusMsg(i18n("Ready."));
 }
    
+// Attach Function to currently opened debugger
+void KPoGreController::slotDebugFunctionAttach()
+{
+	slotStatusMsg(i18n("Attach function to debugger ..."));
+	
+	m_pView->debugFunctionAttach();
+	slotStatusMsg(i18n("Ready."));
+} 
 
 // Run Create Sequence Wizard 
 void KPoGreController::slotCreateSequence()
@@ -1683,6 +1693,12 @@ void KPoGreController::slotSelectionChanged( const KPGTreeItem::eNodeType nodeTy
 			{
 				pAct->setEnabled(bVersion8_3 && (pFunction->langName() == "plpgsql")); // Allow debug only plpgsql function
 			}
+			
+			pAct = pActionCollection->action("debug_function_attach");
+			if(pAct)
+			{
+				pAct->setEnabled(bVersion8_3 && (pFunction->langName() == "plpgsql")); // Allow debug only plpgsql function
+			}
       	}
       	break;
       
