@@ -85,7 +85,7 @@ public:
 	~KPGOidLink() {;}
 
 	// Return PostgreSQL row identifier
-	const pqxx::oid oid() const { return m_oid; }
+	pqxx::oid oid() const { return m_oid; }
 		
 	// Return path
 	const QString & path() const { return m_strPath; }
@@ -149,8 +149,7 @@ public:
 	KPGFunction *);
 	
 	// Create new KPGDebuggerChildView
-    KPGDebuggerChildView * createDebuggerChildView(KPGConnection *, const QString &, 
-	KPGFunction *);
+	KPGDebuggerChildView * createDebuggerChildView(KPGConnection *, const QString &, KPGFunction *, const QString&, pqxx::oid);
     
     // Request to close active MDI child window
     bool requestClose();
@@ -402,6 +401,7 @@ public:
 	void revokePrivilegesFunction();
 	void executeFunction();
 	void debugFunction();
+	void debugFunctionAttach();
 		
 	//--- Sequence related menu actions
 	void createSequence();
